/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIAddrDBAnnouncer.idl
 */

#ifndef __gen_nsIAddrDBAnnouncer_h__
#define __gen_nsIAddrDBAnnouncer_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIAbCard_h__
#include "nsIAbCard.h"
#endif

#ifndef __gen_nsIAbDirectory_h__
#include "nsIAbDirectory.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAddrDBListener; /* forward declaration */


/* starting interface:    nsIAddrDBAnnouncer */
#define NS_IADDRDBANNOUNCER_IID_STR "166b19a1-1235-4613-9601-816dedc48c9e"

#define NS_IADDRDBANNOUNCER_IID \
  {0x166b19a1, 0x1235, 0x4613, \
    { 0x96, 0x01, 0x81, 0x6d, 0xed, 0xc4, 0x8c, 0x9e }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIAddrDBAnnouncer : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IADDRDBANNOUNCER_IID)

  /* void addListener (in nsIAddrDBListener listener); */
  NS_SCRIPTABLE NS_IMETHOD AddListener(nsIAddrDBListener *listener) = 0;

  /* void removeListener (in nsIAddrDBListener listener); */
  NS_SCRIPTABLE NS_IMETHOD RemoveListener(nsIAddrDBListener *listener) = 0;

  /* void notifyCardAttribChange (in unsigned long abCode); */
  NS_SCRIPTABLE NS_IMETHOD NotifyCardAttribChange(PRUint32 abCode) = 0;

  /**
   * Notify all the listeners of the database about an event performed
   * on a card entry.
   *
   * @param     aAbCode               The code to indicate the type of event
   *                                  (see nsAddrDatabase.h AB_NOTIFY_CODE for values).
   * @param     aCard                 The card entry on which the event occurred.
   * @param     aParent               The parent of card entry. This is set by
   *                                  object which performs the operation.
   */
  /* void notifyCardEntryChange (in unsigned long aAbCode, in nsIAbCard aCard, in nsIAbDirectory aParent); */
  NS_SCRIPTABLE NS_IMETHOD NotifyCardEntryChange(PRUint32 aAbCode, nsIAbCard *aCard, nsIAbDirectory *aParent) = 0;

  /* void notifyAnnouncerGoingAway (); */
  NS_SCRIPTABLE NS_IMETHOD NotifyAnnouncerGoingAway(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAddrDBAnnouncer, NS_IADDRDBANNOUNCER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIADDRDBANNOUNCER \
  NS_SCRIPTABLE NS_IMETHOD AddListener(nsIAddrDBListener *listener); \
  NS_SCRIPTABLE NS_IMETHOD RemoveListener(nsIAddrDBListener *listener); \
  NS_SCRIPTABLE NS_IMETHOD NotifyCardAttribChange(PRUint32 abCode); \
  NS_SCRIPTABLE NS_IMETHOD NotifyCardEntryChange(PRUint32 aAbCode, nsIAbCard *aCard, nsIAbDirectory *aParent); \
  NS_SCRIPTABLE NS_IMETHOD NotifyAnnouncerGoingAway(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIADDRDBANNOUNCER(_to) \
  NS_SCRIPTABLE NS_IMETHOD AddListener(nsIAddrDBListener *listener) { return _to AddListener(listener); } \
  NS_SCRIPTABLE NS_IMETHOD RemoveListener(nsIAddrDBListener *listener) { return _to RemoveListener(listener); } \
  NS_SCRIPTABLE NS_IMETHOD NotifyCardAttribChange(PRUint32 abCode) { return _to NotifyCardAttribChange(abCode); } \
  NS_SCRIPTABLE NS_IMETHOD NotifyCardEntryChange(PRUint32 aAbCode, nsIAbCard *aCard, nsIAbDirectory *aParent) { return _to NotifyCardEntryChange(aAbCode, aCard, aParent); } \
  NS_SCRIPTABLE NS_IMETHOD NotifyAnnouncerGoingAway(void) { return _to NotifyAnnouncerGoingAway(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIADDRDBANNOUNCER(_to) \
  NS_SCRIPTABLE NS_IMETHOD AddListener(nsIAddrDBListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddListener(listener); } \
  NS_SCRIPTABLE NS_IMETHOD RemoveListener(nsIAddrDBListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveListener(listener); } \
  NS_SCRIPTABLE NS_IMETHOD NotifyCardAttribChange(PRUint32 abCode) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyCardAttribChange(abCode); } \
  NS_SCRIPTABLE NS_IMETHOD NotifyCardEntryChange(PRUint32 aAbCode, nsIAbCard *aCard, nsIAbDirectory *aParent) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyCardEntryChange(aAbCode, aCard, aParent); } \
  NS_SCRIPTABLE NS_IMETHOD NotifyAnnouncerGoingAway(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyAnnouncerGoingAway(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAddrDBAnnouncer : public nsIAddrDBAnnouncer
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIADDRDBANNOUNCER

  nsAddrDBAnnouncer();

private:
  ~nsAddrDBAnnouncer();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAddrDBAnnouncer, nsIAddrDBAnnouncer)

nsAddrDBAnnouncer::nsAddrDBAnnouncer()
{
  /* member initializers and constructor code */
}

nsAddrDBAnnouncer::~nsAddrDBAnnouncer()
{
  /* destructor code */
}

/* void addListener (in nsIAddrDBListener listener); */
NS_IMETHODIMP nsAddrDBAnnouncer::AddListener(nsIAddrDBListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeListener (in nsIAddrDBListener listener); */
NS_IMETHODIMP nsAddrDBAnnouncer::RemoveListener(nsIAddrDBListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyCardAttribChange (in unsigned long abCode); */
NS_IMETHODIMP nsAddrDBAnnouncer::NotifyCardAttribChange(PRUint32 abCode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyCardEntryChange (in unsigned long aAbCode, in nsIAbCard aCard, in nsIAbDirectory aParent); */
NS_IMETHODIMP nsAddrDBAnnouncer::NotifyCardEntryChange(PRUint32 aAbCode, nsIAbCard *aCard, nsIAbDirectory *aParent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyAnnouncerGoingAway (); */
NS_IMETHODIMP nsAddrDBAnnouncer::NotifyAnnouncerGoingAway()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAddrDBAnnouncer_h__ */
